==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressObjectMetaBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressObjectMetaBuilder extends ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressObjectMetaBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressObjectMeta,ACMEChallengeSolverHTTP01IngressObjectMetaBuilder>{
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressObjectMeta instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withLabels(instance.getLabels());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMeta instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withLabels(instance.getLabels());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressObjectMeta build() {
    ACMEChallengeSolverHTTP01IngressObjectMeta buildable = new ACMEChallengeSolverHTTP01IngressObjectMeta(fluent.getAnnotations(),fluent.getLabels());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressObjectMetaBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressObjectMetaBuilder extends ACMEChallengeSolverHTTP01IngressObjectMetaFluent<ACMEChallengeSolverHTTP01IngressObjectMetaBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressObjectMeta,ACMEChallengeSolverHTTP01IngressObjectMetaBuilder>{
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressObjectMeta(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent,ACMEChallengeSolverHTTP01IngressObjectMeta instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressObjectMeta());

    if (instance != null) {
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withLabels(instance.getLabels());
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withLabels(instance.getLabels());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMeta instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(ACMEChallengeSolverHTTP01IngressObjectMeta instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressObjectMeta());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withLabels(instance.getLabels());
      this.withAnnotations(instance.getAnnotations());
      this.withLabels(instance.getLabels());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressObjectMetaFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressObjectMeta build() {
    ACMEChallengeSolverHTTP01IngressObjectMeta buildable = new ACMEChallengeSolverHTTP01IngressObjectMeta(fluent.getAnnotations(),fluent.getLabels());
    return buildable;
  }
  
}
